@@ -626,9 +626,7 @@ class WordType(caching.base.CachingMixin,models.Model):
             self.save()
         return Freq
 
-    def get_NDs(self,subset='all',speaker=None,dialog=None):
-        if subset == 'all' and self.ND is not None and self.FWND is not None:
-            return self.ND,self.FWND
+    def get_neighbours(self):
         any_segment = '[A-Za-z]{1,2}'
         phones = map(str,self.UR.all())
         patterns = []
@@ -644,10 +642,19 @@ class WordType(caching.base.CachingMixin,models.Model):
             patt.append(any_segment)
             patt.extend(phones[i:])
             patterns.append('^'+' '.join(patt) +'$')
-        neighs = WordType.objects.filter(Label__regex="^[^{<]").extra(
+        patt = phones + [any_segment]
+        patterns.append('^'+' '.join(patt) +'$')
+        neighs = WordType.objects.filter(Label__regex="^[^{<]").exclude(pk=self.pk).extra(
                     where = [UR_LOOKUP],
                     params = ['|'.join(patterns)])
-        freqs = [ x.get_frequency(subset=subset,speaker=speaker,dialog=dialog) for x in neighs]
+        return neighs
+
+
+    def get_NDs(self,subset='all',speaker=None,dialog=None):
+        if subset == 'all' and self.ND is not None and self.FWND is not None:
+            return self.ND,self.FWND
+        freqs = [ x.get_frequency(subset=subset,speaker=speaker,dialog=dialog)
+                        for x in self.get_neighbours()]
         nd = sum([1 for x in freqs if x > 0])
         fwnd = sum(freqs)
         if subset == 'all':
